function varargout=inputui(title_txt,text,values,filename)
  // A single line frontend for x_mdialog, with some additional functionality.
  // Calling sequence
  //  [varargout]=inputui(title_txt,text[,values][,filename])
  // Parameters
  //  title_txt : title text
  //  text : list() with text labels for each input variable to be retrieved.
  //  values : optional list() with default values for each input variable. 
  //  filename : optional file name for retrieval of default values stored by a previous call to inputui.
  // Description
  //  inputui is a front end for the Scilab function x_mdialog which only require a single command line.
  //  
  //  Values may be stored between successive calls to inputui within the current Scilab session. 
  //  The values are stored in the TMPDIR directory as a file named [filename] (see the optional fourth input parameter). 
  //  Note that these values are only stored during the current Scilab session.
  //  Use unique values for [filename] in order to store values for different types of calls to inputui.
  //   
  // Examples
  //  [a,b,c]=inputui('Test',list('a','b','c'),list(1,2,3));  // Single line call...
  //
  //  // Store values between successive calls to inputui... 
  //  [a,b]=inputui('Edit a and b',list('a','b'),list(1,2),'inputui_demo') // change the values for a and b and press OK.
  //
  //  [a,b]=inputui('Test',list('a','b'),list(1,2),'inputui_demo') // default values are now retrieved from TMP\inputui_demo
  // See also
  //  x_mdialog
  //  guimaker
  // Authors
  //  T. Pettersen 

  //
  //  $Id: $
  //
  //  torbjorn.pettersen@broadpark.no
  
//  Copyright Torbjrn Pettersen  2008
//
//  This software is governed by the CeCILL  license under French law and
//  abiding by the rules of distribution of free software.  You can  use, 
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  "http://www.cecill.info". 
//
//  As a counterpart to the access to the source code and  rights to copy,
//  modify and redistribute granted by the license, users are provided only
//  with a limited warranty  and the software's author,  the holder of the
//  economic rights,  and the successive licensors  have only  limited
//  liability. 
//
//  In this respect, the user's attention is drawn to the risks associated
//  with loading,  using,  modifying and/or developing or reproducing the
//  software by the user in light of its specific status of free software,
//  that may mean  that it is complicated to manipulate,  and  that  also
//  therefore means  that it is reserved for developers  and  experienced
//  professionals having in-depth computer knowledge. Users are therefore
//  encouraged to load and test the software's suitability as regards their
//  requirements in conditions enabling the security of their systems and/or
//  data to be ensured and,  more generally, to use and operate it in the 
//  same conditions as regards security. 
//
//  The fact that you are presently reading this means that you have had
//  knowledge of the CeCILL license and that you accept its terms.

  if argn(2)<3 | isempty(values) then 
    values=list();
    for i=1:length(text), values(i)=[]; end
  end
  if length(text)<>length(values) then error('Number of text strings does not match number of default values'); end
  if length(values)<>argn(1) then error('Number of output arguments does not match number of default values'); end
    
  if argn(2)<4 then filename=''; end
  if ~isempty(fileinfo(TMPDIR+'\'+filename+'.dat')) then 
    load(TMPDIR+'\'+filename+'.dat'); 
  end

  val=[]; txt=[];
  for i=1:length(values), 
    [m,n]=size(values(i)); 
    if m*n>1 then
      str='[';
      for k=1:m
        for l=1:n
          str=str+sprintf('%g ',values(i)(k,l));
        end
        if k<m then str=str+';'; end;
      end
      str=str+']';
      val=[val;str];
    else
      if type(values(i))==1 then
        if values(i)==[] then val=[val;'[]']; else val=[val;string(values(i))]; end
      else
        val=[val;sprintf('''%s''',values(i))];
      end
    end
    txt=[txt;text(i)]; 
  end

  sig=x_mdialog(title_txt,txt,val);
  
  if ~isempty(sig) then 
    for i=1:length(values), 
      if isempty(sig(i)) then 
        varargout(i)=''; 
      else 
        try
          varargout(i)=evstr(sig(i));
        catch
          tmp=tokens(sig(i));
          if isnum(tmp(1)) then 
            varargout(i)=evstr(sig(i)); 
          else  
            varargout(i)=sprintf('%s',sig(i)); 
          end
        end
      end; 
    end;
  else
    for i=1:length(values), varargout(i)=[]; end;
    return
  end  

  if ~isempty(filename) then
    values=varargout;
    save(TMPDIR+'\'+filename+'.dat',values);
  end 
endfunction
